/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton implementation for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.3"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 1

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_NUMBER = 258,
     T_STRING = 259,
     T_NEWLINE = 260,
     T_PIXELSET = 261,
     T_PIXELFILL = 262,
     T_PIXELRFILL = 263,
     T_PIXELOVERLAY = 264,
     T_PIXELBOX = 265,
     T_PIXELCLEAR = 266,
     T_DRAWLINE = 267,
     T_DRAWCIRCLE = 268,
     T_DRAWRBOX = 269,
     T_DRAWBAR = 270,
     T_DRAWNUM = 271,
     T_DRAWICON = 272,
     T_DRAWSPRITE = 273,
     T_WBMPSPLASH = 274,
     T_WBMPLOAD = 275,
     T_MODECACHE = 276,
     T_MODEREV = 277,
     T_MODEXOR = 278,
     T_MODEPRI = 279,
     T_FONTLOAD = 280,
     T_FONTPRINT = 281,
     T_TEXTSMALL = 282,
     T_TEXTMED = 283,
     T_TEXTLARGE = 284,
     T_TEXTOVERLAY = 285,
     T_KEYL = 286,
     T_KEYM = 287,
     T_LCDBL = 288,
     T_LCDCON = 289,
     T_SCREENNEW = 290,
     T_SCREENCLOSE = 291
   };
#endif
/* Tokens.  */
#define T_NUMBER 258
#define T_STRING 259
#define T_NEWLINE 260
#define T_PIXELSET 261
#define T_PIXELFILL 262
#define T_PIXELRFILL 263
#define T_PIXELOVERLAY 264
#define T_PIXELBOX 265
#define T_PIXELCLEAR 266
#define T_DRAWLINE 267
#define T_DRAWCIRCLE 268
#define T_DRAWRBOX 269
#define T_DRAWBAR 270
#define T_DRAWNUM 271
#define T_DRAWICON 272
#define T_DRAWSPRITE 273
#define T_WBMPSPLASH 274
#define T_WBMPLOAD 275
#define T_MODECACHE 276
#define T_MODEREV 277
#define T_MODEXOR 278
#define T_MODEPRI 279
#define T_FONTLOAD 280
#define T_FONTPRINT 281
#define T_TEXTSMALL 282
#define T_TEXTMED 283
#define T_TEXTLARGE 284
#define T_TEXTOVERLAY 285
#define T_KEYL 286
#define T_KEYM 287
#define T_LCDBL 288
#define T_LCDCON 289
#define T_SCREENNEW 290
#define T_SCREENCLOSE 291




/* Copy the first part of user declarations.  */
#line 1 "g15composer.y"

/*
    This file is part of g15tools.

    g15tools is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    g15tools is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with g15tools; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/stat.h>
#include <pthread.h>
#include <libg15.h>
#include <libg15render.h>
#include <g15daemon_client.h>

#include "g15composer.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define YYPARSE_PARAM param
#define YYLEX_PARAM   ((struct parserData *)param)->scanner
#define YYERROR_VERBOSE true

int yydebug = 0;



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* Enabling the token table.  */
#ifndef YYTOKEN_TABLE
# define YYTOKEN_TABLE 0
#endif

#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 45 "g15composer.y"
{
	int number;
	char *string;
	struct strList *strList;
}
/* Line 187 of yacc.c.  */
#line 217 "g15composer.tab.c"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 216 of yacc.c.  */
#line 230 "g15composer.tab.c"

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#elif (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
typedef signed char yytype_int8;
#else
typedef short int yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(e) ((void) (e))
#else
# define YYUSE(e) /* empty */
#endif

/* Identity function, used to suppress warnings about constant conditions.  */
#ifndef lint
# define YYID(n) (n)
#else
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static int
YYID (int i)
#else
static int
YYID (i)
    int i;
#endif
{
  return i;
}
#endif

#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#     ifndef _STDLIB_H
#      define _STDLIB_H 1
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (YYID (0))
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined _STDLIB_H \
       && ! ((defined YYMALLOC || defined malloc) \
	     && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef _STDLIB_H
#    define _STDLIB_H 1
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
	 || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  YYSIZE_T yyi;				\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (YYID (0))
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (YYID (0))

#endif

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   212

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  37
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  18
/* YYNRULES -- Number of rules.  */
#define YYNRULES  57
/* YYNRULES -- Number of states.  */
#define YYNSTATES  184

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   291

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const yytype_uint16 yyprhs[] =
{
       0,     0,     3,     4,     7,    11,    13,    15,    17,    19,
      21,    23,    25,    27,    29,    31,    32,    35,    41,    49,
      55,    63,    65,    69,    76,    84,    93,   103,   111,   120,
     126,   136,   138,   140,   142,   149,   157,   165,   174,   184,
     195,   199,   204,   208,   212,   216,   220,   226,   236,   240,
     244,   248,   256,   260,   265,   269,   273,   277
};

/* YYRHS -- A `-1'-separated list of the rules' RHS.  */
static const yytype_int8 yyrhs[] =
{
      38,     0,    -1,    -1,    38,    39,    -1,    38,     1,    39,
      -1,    42,    -1,    44,    -1,    48,    -1,    49,    -1,    50,
      -1,    51,    -1,    52,    -1,    53,    -1,    54,    -1,     4,
      -1,    -1,    41,    40,    -1,     6,     3,     3,     3,     5,
      -1,     7,     3,     3,     3,     3,     3,     5,    -1,     8,
       3,     3,     3,     3,    -1,     9,     3,     3,     3,     3,
      40,     5,    -1,    43,    -1,    11,     3,     5,    -1,    10,
       3,     3,     3,     3,     5,    -1,    10,     3,     3,     3,
       3,     3,     5,    -1,    10,     3,     3,     3,     3,     3,
       3,     5,    -1,    10,     3,     3,     3,     3,     3,     3,
       3,     5,    -1,    12,     3,     3,     3,     3,     3,     5,
      -1,    16,     3,     3,     3,     3,     3,     3,     5,    -1,
      17,     3,     3,     3,     5,    -1,    18,     3,     3,     3,
       3,     3,     3,     3,     5,    -1,    45,    -1,    46,    -1,
      47,    -1,    13,     3,     3,     3,     3,     5,    -1,    13,
       3,     3,     3,     3,     3,     5,    -1,    14,     3,     3,
       3,     3,     3,     5,    -1,    14,     3,     3,     3,     3,
       3,     3,     5,    -1,    15,     3,     3,     3,     3,     3,
       3,     3,     5,    -1,    15,     3,     3,     3,     3,     3,
       3,     3,     3,     5,    -1,    19,    40,     5,    -1,    20,
       3,    40,     5,    -1,    21,     3,     5,    -1,    22,     3,
       5,    -1,    23,     3,     5,    -1,    24,     3,     5,    -1,
      25,     3,     3,    40,     5,    -1,    26,     3,     3,     3,
       3,     3,     3,    40,     5,    -1,    27,    41,     5,    -1,
      28,    41,     5,    -1,    29,    41,     5,    -1,    30,     3,
       3,     3,     3,    41,     5,    -1,    31,     3,     5,    -1,
      32,     3,     3,     5,    -1,    33,     3,     5,    -1,    34,
       3,     5,    -1,    35,    40,     5,    -1,    36,     5,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,    93,    93,    94,   107,   111,   112,   113,   114,   115,
     116,   130,   131,   132,   136,   143,   149,   157,   166,   175,
     184,   212,   216,   225,   234,   243,   252,   261,   270,   279,
     297,   314,   316,   318,   322,   331,   340,   349,   358,   367,
     376,   386,   400,   412,   421,   430,   475,   487,   499,   516,
     533,   550,   576,   582,   636,   647,   658,   672
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "T_NUMBER", "T_STRING", "T_NEWLINE",
  "T_PIXELSET", "T_PIXELFILL", "T_PIXELRFILL", "T_PIXELOVERLAY",
  "T_PIXELBOX", "T_PIXELCLEAR", "T_DRAWLINE", "T_DRAWCIRCLE", "T_DRAWRBOX",
  "T_DRAWBAR", "T_DRAWNUM", "T_DRAWICON", "T_DRAWSPRITE", "T_WBMPSPLASH",
  "T_WBMPLOAD", "T_MODECACHE", "T_MODEREV", "T_MODEXOR", "T_MODEPRI",
  "T_FONTLOAD", "T_FONTPRINT", "T_TEXTSMALL", "T_TEXTMED", "T_TEXTLARGE",
  "T_TEXTOVERLAY", "T_KEYL", "T_KEYM", "T_LCDBL", "T_LCDCON",
  "T_SCREENNEW", "T_SCREENCLOSE", "$accept", "nt_commands", "nt_command",
  "nt_string", "nt_strings", "nt_pixel_command", "nt_pixelbox",
  "nt_draw_command", "nt_drawcircle", "nt_drawrbox", "nt_drawbar",
  "nt_wbmp_command", "nt_mode_command", "nt_font_command",
  "nt_text_command", "nt_key_command", "nt_lcd_command",
  "nt_screen_command", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    37,    38,    38,    38,    39,    39,    39,    39,    39,
      39,    39,    39,    39,    40,    41,    41,    42,    42,    42,
      42,    42,    42,    43,    43,    43,    43,    44,    44,    44,
      44,    44,    44,    44,    45,    45,    46,    46,    47,    47,
      48,    48,    49,    49,    49,    49,    50,    50,    51,    51,
      51,    51,    52,    52,    53,    53,    54,    54
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     0,     2,     3,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     0,     2,     5,     7,     5,
       7,     1,     3,     6,     7,     8,     9,     7,     8,     5,
       9,     1,     1,     1,     6,     7,     7,     8,     9,    10,
       3,     4,     3,     3,     3,     3,     5,     9,     3,     3,
       3,     7,     3,     4,     3,     3,     3,     2
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       2,     0,     1,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    15,    15,    15,     0,     0,
       0,     0,     0,     0,     0,     3,     5,    21,     6,    31,
      32,    33,     7,     8,     9,    10,    11,    12,    13,     4,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    14,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    57,     0,     0,     0,     0,     0,    22,     0,     0,
       0,     0,     0,     0,     0,    40,     0,    42,    43,    44,
      45,     0,     0,    48,    16,    49,    50,     0,    52,     0,
      54,    55,    56,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    41,     0,     0,     0,    53,
      17,     0,    19,     0,     0,     0,     0,     0,     0,     0,
      29,     0,    46,     0,    15,     0,     0,     0,    23,     0,
       0,    34,     0,     0,     0,     0,     0,     0,    18,    20,
       0,    24,    27,    35,     0,    36,     0,     0,     0,     0,
      51,     0,    25,    37,     0,    28,     0,     0,    26,     0,
      38,    30,    47,    39
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int8 yydefgoto[] =
{
      -1,     1,    35,   104,    72,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -26
static const yytype_int16 yypact[] =
{
     -26,    11,   -26,    43,    78,    80,    90,    91,    92,    93,
      94,    95,    96,    97,    98,    99,   100,   101,   103,   104,
     105,   106,   107,   108,   109,   -26,   -26,   -26,   110,   111,
     112,   114,   115,   101,     9,   -26,   -26,   -26,   -26,   -26,
     -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26,
     117,   118,   119,   120,   121,   122,   123,   125,   126,   127,
     128,   129,   130,   -26,   131,   101,   132,   133,   134,   135,
     138,   139,    81,    83,    85,   140,   141,   142,   143,   144,
     145,   -26,   148,   150,   151,   152,   153,   -26,   154,   155,
     156,   157,   158,   159,   160,   -26,   161,   -26,   -26,   -26,
     -26,   101,   162,   -26,   -26,   -26,   -26,   164,   -26,   163,
     -26,   -26,   -26,   165,   166,   168,   169,   170,   171,   172,
     173,   174,   175,   176,   177,   -26,   178,   179,   181,   -26,
     -26,   182,   -26,   101,     0,   183,     1,   184,   185,   186,
     -26,   187,   -26,   188,   -26,   189,   190,     4,   -26,   191,
     192,   -26,     5,   195,   196,   197,   198,    87,   -26,   -26,
      10,   -26,   -26,   -26,   199,   -26,   200,   201,   202,   101,
     -26,   203,   -26,   -26,    77,   -26,   204,   205,   -26,   206,
     -26,   -26,   -26,   -26
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
     -26,   -26,   209,   -17,   -25,   -26,   -26,   -26,   -26,   -26,
     -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const yytype_uint8 yytable[] =
{
      64,    73,    74,   147,   150,   148,   151,   160,   164,   161,
     165,     2,     3,   171,    81,   172,    80,     4,     5,     6,
       7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    33,    34,    96,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
     179,    50,   180,    51,   126,    63,   103,    63,   105,    63,
     106,    63,   170,    52,    53,    54,    55,    56,    57,    58,
      59,    60,    61,    62,     0,    63,    65,    66,    67,    68,
      69,    70,    71,    75,    76,    77,   146,    78,    79,   157,
      82,    83,    84,    85,    86,     0,    88,    87,    89,    90,
      91,    92,    93,    94,     0,     0,    95,    97,    98,    99,
     100,   101,   102,   107,     0,   109,   108,     0,   110,   111,
     112,   113,   177,   114,   115,   116,   117,   118,   119,   120,
     121,   122,   123,   124,     0,   127,   125,   128,   129,   131,
     130,   132,   133,   134,   135,   136,   137,   138,   139,     0,
     141,   140,   143,   142,   144,   145,   149,   152,   153,   154,
     155,   156,     0,     0,   158,   159,   162,   163,   166,   167,
     168,   169,     0,   174,   173,   176,   175,     0,   178,   181,
     182,   183,    49
};

static const yytype_int16 yycheck[] =
{
      17,    26,    27,     3,     3,     5,     5,     3,     3,     5,
       5,     0,     1,     3,     5,     5,    33,     6,     7,     8,
       9,    10,    11,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    35,    36,    65,     6,
       7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
       3,     3,     5,     3,   101,     4,     5,     4,     5,     4,
       5,     4,     5,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,    -1,     4,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,   133,     3,     3,   144,
       3,     3,     3,     3,     3,    -1,     3,     5,     3,     3,
       3,     3,     3,     3,    -1,    -1,     5,     5,     5,     5,
       5,     3,     3,     3,    -1,     3,     5,    -1,     5,     5,
       5,     3,   169,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,    -1,     3,     5,     3,     5,     3,
       5,     3,     3,     3,     3,     3,     3,     3,     3,    -1,
       3,     5,     3,     5,     3,     3,     3,     3,     3,     3,
       3,     3,    -1,    -1,     5,     5,     5,     5,     3,     3,
       3,     3,    -1,     3,     5,     3,     5,    -1,     5,     5,
       5,     5,     3
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    38,     0,     1,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    35,    36,    39,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    39,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     4,    40,     3,     3,     3,     3,     3,
       3,     3,    41,    41,    41,     3,     3,     3,     3,     3,
      40,     5,     3,     3,     3,     3,     3,     5,     3,     3,
       3,     3,     3,     3,     3,     5,    40,     5,     5,     5,
       5,     3,     3,     5,    40,     5,     5,     3,     5,     3,
       5,     5,     5,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     5,    40,     3,     3,     5,
       5,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       5,     3,     5,     3,     3,     3,    40,     3,     5,     3,
       3,     5,     3,     3,     3,     3,     3,    41,     5,     5,
       3,     5,     5,     5,     3,     5,     3,     3,     3,     3,
       5,     3,     5,     5,     3,     5,     3,    40,     5,     3,
       5,     5,     5,     5
};

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK (1);						\
      goto yybackup;						\
    }								\
  else								\
    {								\
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (YYID (0))


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (YYID (N))                                                    \
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (YYID (0))
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
	      (Loc).first_line, (Loc).first_column,	\
	      (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (&yylval, YYLEX_PARAM)
#else
# define YYLEX yylex (&yylval)
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (YYID (0))

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)			  \
do {									  \
  if (yydebug)								  \
    {									  \
      YYFPRINTF (stderr, "%s ", Title);					  \
      yy_symbol_print (stderr,						  \
		  Type, Value); \
      YYFPRINTF (stderr, "\n");						  \
    }									  \
} while (YYID (0))


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_value_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# else
  YYUSE (yyoutput);
# endif
  switch (yytype)
    {
      default:
	break;
    }
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (yytype < YYNTOKENS)
    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
#else
static void
yy_stack_print (bottom, top)
    yytype_int16 *bottom;
    yytype_int16 *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (YYID (0))


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
#else
static void
yy_reduce_print (yyvsp, yyrule)
    YYSTYPE *yyvsp;
    int yyrule;
#endif
{
  int yynrhs = yyr2[yyrule];
  int yyi;
  unsigned long int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
	     yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      fprintf (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
		       &(yyvsp[(yyi + 1) - (yynrhs)])
		       		       );
      fprintf (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (yyvsp, Rule); \
} while (YYID (0))

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static YYSIZE_T
yystrlen (const char *yystr)
#else
static YYSIZE_T
yystrlen (yystr)
    const char *yystr;
#endif
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static char *
yystpcpy (char *yydest, const char *yysrc)
#else
static char *
yystpcpy (yydest, yysrc)
    char *yydest;
    const char *yysrc;
#endif
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
	switch (*++yyp)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++yyp != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (yyres)
	      yyres[yyn] = *yyp;
	    yyn++;
	    break;

	  case '"':
	    if (yyres)
	      yyres[yyn] = '\0';
	    return yyn;
	  }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into YYRESULT an error message about the unexpected token
   YYCHAR while in state YYSTATE.  Return the number of bytes copied,
   including the terminating null byte.  If YYRESULT is null, do not
   copy anything; just return the number of bytes that would be
   copied.  As a special case, return 0 if an ordinary "syntax error"
   message will do.  Return YYSIZE_MAXIMUM if overflow occurs during
   size calculation.  */
static YYSIZE_T
yysyntax_error (char *yyresult, int yystate, int yychar)
{
  int yyn = yypact[yystate];

  if (! (YYPACT_NINF < yyn && yyn <= YYLAST))
    return 0;
  else
    {
      int yytype = YYTRANSLATE (yychar);
      YYSIZE_T yysize0 = yytnamerr (0, yytname[yytype]);
      YYSIZE_T yysize = yysize0;
      YYSIZE_T yysize1;
      int yysize_overflow = 0;
      enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
      char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
      int yyx;

# if 0
      /* This is so xgettext sees the translatable formats that are
	 constructed on the fly.  */
      YY_("syntax error, unexpected %s");
      YY_("syntax error, unexpected %s, expecting %s");
      YY_("syntax error, unexpected %s, expecting %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
# endif
      char *yyfmt;
      char const *yyf;
      static char const yyunexpected[] = "syntax error, unexpected %s";
      static char const yyexpecting[] = ", expecting %s";
      static char const yyor[] = " or %s";
      char yyformat[sizeof yyunexpected
		    + sizeof yyexpecting - 1
		    + ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
		       * (sizeof yyor - 1))];
      char const *yyprefix = yyexpecting;

      /* Start YYX at -YYN if negative to avoid negative indexes in
	 YYCHECK.  */
      int yyxbegin = yyn < 0 ? -yyn : 0;

      /* Stay within bounds of both yycheck and yytname.  */
      int yychecklim = YYLAST - yyn + 1;
      int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
      int yycount = 1;

      yyarg[0] = yytname[yytype];
      yyfmt = yystpcpy (yyformat, yyunexpected);

      for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	  {
	    if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
	      {
		yycount = 1;
		yysize = yysize0;
		yyformat[sizeof yyunexpected - 1] = '\0';
		break;
	      }
	    yyarg[yycount++] = yytname[yyx];
	    yysize1 = yysize + yytnamerr (0, yytname[yyx]);
	    yysize_overflow |= (yysize1 < yysize);
	    yysize = yysize1;
	    yyfmt = yystpcpy (yyfmt, yyprefix);
	    yyprefix = yyor;
	  }

      yyf = YY_(yyformat);
      yysize1 = yysize + yystrlen (yyf);
      yysize_overflow |= (yysize1 < yysize);
      yysize = yysize1;

      if (yysize_overflow)
	return YYSIZE_MAXIMUM;

      if (yyresult)
	{
	  /* Avoid sprintf, as that infringes on the user's name space.
	     Don't have undefined behavior even if the translation
	     produced a string with the wrong number of "%s"s.  */
	  char *yyp = yyresult;
	  int yyi = 0;
	  while ((*yyp = *yyf) != '\0')
	    {
	      if (*yyp == '%' && yyf[1] == 's' && yyi < yycount)
		{
		  yyp += yytnamerr (yyp, yyarg[yyi++]);
		  yyf += 2;
		}
	      else
		{
		  yyp++;
		  yyf++;
		}
	    }
	}
      return yysize;
    }
}
#endif /* YYERROR_VERBOSE */


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yymsg, yytype, yyvaluep)
    const char *yymsg;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  YYUSE (yyvaluep);

  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  switch (yytype)
    {

      default:
	break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int yyparse (void *YYPARSE_PARAM);
#else
int yyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */






/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void *YYPARSE_PARAM)
#else
int
yyparse (YYPARSE_PARAM)
    void *YYPARSE_PARAM;
#endif
#else /* ! YYPARSE_PARAM */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  /* The look-ahead symbol.  */
int yychar;

/* The semantic value of the look-ahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;

  int yystate;
  int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Look-ahead token as an internal (translated) token number.  */
  int yytoken = 0;
#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  yytype_int16 yyssa[YYINITDEPTH];
  yytype_int16 *yyss = yyssa;
  yytype_int16 *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  YYSTYPE *yyvsp;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack.  Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	yytype_int16 *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow (YY_("memory exhausted"),
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	yytype_int16 *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyexhaustedlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     look-ahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to look-ahead token.  */
  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a look-ahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the look-ahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  yystate = yyn;
  *++yyvsp = yylval;

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 3:
#line 95 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		if (((struct parserData *)param)->leaving != 1 && ((struct parserData *)param)->cmd_only!=1)
		  updateScreen (((struct parserData *)param)->canvas, ((struct parserData *)param)->g15screen_fd, 0);
		else
		  ((struct parserData *)param)->cmd_only=0;

	}
    break;

  case 10:
#line 117 "g15composer.y"
    {
		((struct parserData *)param)->itemptr = ((struct parserData *)param)->listptr->first_string;
		while (((struct parserData *)param)->itemptr != 0)
		  {
		  	free (((struct parserData *)param)->itemptr->string);
			struct strItem *tmpItem = ((struct parserData *)param)->itemptr;
			((struct parserData *)param)->itemptr = ((struct parserData *)param)->itemptr->next_string;
			free (tmpItem);
		  }
		free (((struct parserData *)param)->listptr);
		((struct parserData *)param)->listptr = NULL;
		((struct parserData *)param)->itemptr = NULL;
	}
    break;

  case 14:
#line 137 "g15composer.y"
    {
		(yyval.string) = (yyvsp[(1) - (1)].string);
	}
    break;

  case 15:
#line 143 "g15composer.y"
    {
		(yyval.strList) = new_strList ();
	}
    break;

  case 16:
#line 150 "g15composer.y"
    {
		add_string ((yyvsp[(1) - (2)].strList), (yyvsp[(2) - (2)].string));
		(yyval.strList) = (yyvsp[(1) - (2)].strList);
	}
    break;

  case 17:
#line 158 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_setPixel (((struct parserData *)param)->canvas, (yyvsp[(2) - (5)].number), (yyvsp[(3) - (5)].number), (yyvsp[(4) - (5)].number));
	}
    break;

  case 18:
#line 167 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_pixelReverseFill (((struct parserData *)param)->canvas, (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number), (yyvsp[(4) - (7)].number), (yyvsp[(5) - (7)].number), 1, (yyvsp[(6) - (7)].number));
	}
    break;

  case 19:
#line 176 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_pixelReverseFill (((struct parserData *)param)->canvas, (yyvsp[(2) - (5)].number), (yyvsp[(3) - (5)].number), (yyvsp[(4) - (5)].number), (yyvsp[(5) - (5)].number), 0, G15_COLOR_WHITE);
	}
    break;

  case 20:
#line 185 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		short output_line[G15_BUFFER_LEN];
		int len = strlen ((yyvsp[(6) - (7)].string));
		int exp = (yyvsp[(4) - (7)].number) * (yyvsp[(5) - (7)].number);

		if ((len != exp) || (len > G15_BUFFER_LEN))
		  {
		  	fprintf (stderr, "Error: Expected %d pixels but received %d.\n", exp, len);
			return (1);
		  }

		int i = 0;

		for (i = 0; i < len; ++i)
		  {
	  	    	output_line[i] = 0;
		    	if ((yyvsp[(6) - (7)].string)[i] == '1')
	      	          output_line[i] = 1;
	      	  }
	  	g15r_pixelOverlay (((struct parserData *)param)->canvas, (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number), (yyvsp[(4) - (7)].number), (yyvsp[(5) - (7)].number), output_line);
		free ((yyvsp[(6) - (7)].string));
	}
    break;

  case 22:
#line 217 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_clearScreen (((struct parserData *)param)->canvas, (yyvsp[(2) - (3)].number));
	}
    break;

  case 23:
#line 226 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_pixelBox (((struct parserData *)param)->canvas, (yyvsp[(2) - (6)].number), (yyvsp[(3) - (6)].number), (yyvsp[(4) - (6)].number), (yyvsp[(5) - (6)].number), 1, 1, 0);
	}
    break;

  case 24:
#line 235 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_pixelBox (((struct parserData *)param)->canvas, (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number), (yyvsp[(4) - (7)].number), (yyvsp[(5) - (7)].number), (yyvsp[(6) - (7)].number), 1, 0);
	}
    break;

  case 25:
#line 244 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_pixelBox (((struct parserData *)param)->canvas, (yyvsp[(2) - (8)].number), (yyvsp[(3) - (8)].number), (yyvsp[(4) - (8)].number), (yyvsp[(5) - (8)].number), (yyvsp[(6) - (8)].number), (yyvsp[(7) - (8)].number), 0);
	}
    break;

  case 26:
#line 253 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_pixelBox (((struct parserData *)param)->canvas, (yyvsp[(2) - (9)].number), (yyvsp[(3) - (9)].number), (yyvsp[(4) - (9)].number), (yyvsp[(5) - (9)].number), (yyvsp[(6) - (9)].number), (yyvsp[(7) - (9)].number), (yyvsp[(8) - (9)].number));
	}
    break;

  case 27:
#line 262 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawLine (((struct parserData *)param)->canvas, (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number), (yyvsp[(4) - (7)].number), (yyvsp[(5) - (7)].number), (yyvsp[(6) - (7)].number));
	}
    break;

  case 28:
#line 271 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawBigNum (((struct parserData *)param)->canvas, (yyvsp[(2) - (8)].number), (yyvsp[(3) - (8)].number), (yyvsp[(4) - (8)].number), (yyvsp[(5) - (8)].number), (yyvsp[(6) - (8)].number), (yyvsp[(7) - (8)].number));
	}
    break;

  case 29:
#line 280 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		
		struct bufItem *buf = ((struct parserData *)param)->buflist->first_buf;

		while ((buf->id != (yyvsp[(2) - (5)].number)) && (buf != NULL))
		  buf = buf->next;

		if (buf == NULL)
		  return (-1);

		g15r_drawIcon (((struct parserData *)param)->canvas, buf->buffer, (yyvsp[(3) - (5)].number), (yyvsp[(4) - (5)].number), buf->width, buf->height);
	}
    break;

  case 30:
#line 298 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		
		struct bufItem *buf = ((struct parserData *)param)->buflist->first_buf;

		while ((buf->id != (yyvsp[(2) - (9)].number)) && (buf != NULL))
		  buf = buf->next;

		if (buf == NULL)
		  return (-1);

		g15r_drawSprite (((struct parserData *)param)->canvas, buf->buffer, (yyvsp[(3) - (9)].number), (yyvsp[(4) - (9)].number), (yyvsp[(5) - (9)].number), (yyvsp[(6) - (9)].number), (yyvsp[(7) - (9)].number), (yyvsp[(8) - (9)].number), buf->width);
	}
    break;

  case 34:
#line 323 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawCircle (((struct parserData *)param)->canvas, (yyvsp[(2) - (6)].number), (yyvsp[(3) - (6)].number), (yyvsp[(4) - (6)].number), 0, (yyvsp[(5) - (6)].number));
	}
    break;

  case 35:
#line 332 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawCircle (((struct parserData *)param)->canvas, (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number), (yyvsp[(4) - (7)].number), (yyvsp[(6) - (7)].number), (yyvsp[(5) - (7)].number));
	}
    break;

  case 36:
#line 341 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawRoundBox (((struct parserData *)param)->canvas, (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number), (yyvsp[(4) - (7)].number), (yyvsp[(5) - (7)].number), 0, (yyvsp[(6) - (7)].number));
	}
    break;

  case 37:
#line 350 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawRoundBox (((struct parserData *)param)->canvas, (yyvsp[(2) - (8)].number), (yyvsp[(3) - (8)].number), (yyvsp[(4) - (8)].number), (yyvsp[(5) - (8)].number), (yyvsp[(7) - (8)].number), (yyvsp[(6) - (8)].number));
	}
    break;

  case 38:
#line 359 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawBar (((struct parserData *)param)->canvas, (yyvsp[(2) - (9)].number), (yyvsp[(3) - (9)].number), (yyvsp[(4) - (9)].number), (yyvsp[(5) - (9)].number), (yyvsp[(6) - (9)].number), (yyvsp[(7) - (9)].number), (yyvsp[(8) - (9)].number), 1);
	}
    break;

  case 39:
#line 368 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_drawBar (((struct parserData *)param)->canvas, (yyvsp[(2) - (10)].number), (yyvsp[(3) - (10)].number), (yyvsp[(4) - (10)].number), (yyvsp[(5) - (10)].number), (yyvsp[(6) - (10)].number), (yyvsp[(7) - (10)].number), (yyvsp[(8) - (10)].number), (yyvsp[(9) - (10)].number));
	}
    break;

  case 40:
#line 377 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		g15r_loadWbmpSplash (((struct parserData *)param)->canvas, (yyvsp[(2) - (3)].string));
		free ((yyvsp[(2) - (3)].string));
	}
    break;

  case 41:
#line 387 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		int width = 0;
		int height = 0;

		char *buffer = g15r_loadWbmpToBuf ((yyvsp[(3) - (4)].string), &width, &height);
		int ret = add_buf (((struct parserData *)param)->buflist, (yyvsp[(2) - (4)].number), buffer, width, height);
		free ((yyvsp[(3) - (4)].string));
	}
    break;

  case 42:
#line 401 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		int was_cached = ((struct parserData *)param)->canvas->mode_cache;
		((struct parserData *)param)->canvas->mode_cache = (yyvsp[(2) - (3)].number);
		if (was_cached)
		  updateScreen (((struct parserData *)param)->canvas, ((struct parserData *)param)->g15screen_fd, 1);
	}
    break;

  case 43:
#line 413 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		((struct parserData *)param)->canvas->mode_reverse = (yyvsp[(2) - (3)].number);
	}
    break;

  case 44:
#line 422 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		((struct parserData *)param)->canvas->mode_xor = (yyvsp[(2) - (3)].number);
	}
    break;

  case 45:
#line 431 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);

                int fore = ((yyvsp[(2) - (3)].number) == 0 ? 1 : 0);
                int rear = ((yyvsp[(2) - (3)].number) == 1 ? 1 : 0);
                int revert = ((yyvsp[(2) - (3)].number) == 2 ? 1 : 0);
                                                                                  
                int dummy=0;
                
                int at_front = g15_send_cmd (((struct parserData *)param)->g15screen_fd, G15DAEMON_IS_FOREGROUND, dummy);
                int user_to_front = g15_send_cmd(((struct parserData *)param)->g15screen_fd,G15DAEMON_IS_USER_SELECTED, dummy);

		int sendCmd = 0;
		if (at_front == 1)
		  {
		    if (rear == 1)		/* we want to go to the back */
		      {
			sendCmd = 1;
		      }
		    else if ((user_to_front == 0) && (revert == 1))	/* we want to go to the back if forced to the front */
		      {
			sendCmd = 1;
		      }
		  }
		else
		  {
		    if (fore == 1)		/* we want to go to the front */
		      {
			sendCmd = 1;
		      }
		    else if ((user_to_front == 1) && (revert == 1))	/* we want to take back the foreground if forced to the back */
		      {
			sendCmd = 1;
		      }
		  }
		if (sendCmd == 1){
		  g15_send_cmd(((struct parserData *)param)->g15screen_fd,G15DAEMON_SWITCH_PRIORITIES,dummy);
               }
              ((struct parserData *)param)->cmd_only=1;
	}
    break;

  case 46:
#line 476 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		#ifdef TTF_SUPPORT
		g15r_ttfLoad (((struct parserData *)param)->canvas, (yyvsp[(4) - (5)].string), (yyvsp[(3) - (5)].number), (yyvsp[(2) - (5)].number));
		#endif
		free ((yyvsp[(4) - (5)].string));
	}
    break;

  case 47:
#line 488 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		#ifdef TTF_SUPPORT
		g15r_ttfPrint (((struct parserData *)param)->canvas, (yyvsp[(4) - (9)].number), (yyvsp[(5) - (9)].number), (yyvsp[(3) - (9)].number), (yyvsp[(2) - (9)].number), (yyvsp[(6) - (9)].number), (yyvsp[(7) - (9)].number), (yyvsp[(8) - (9)].string));
		#endif
		free ((yyvsp[(8) - (9)].string));
	}
    break;

  case 48:
#line 500 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		((struct parserData *)param)->listptr = (yyvsp[(2) - (3)].strList);
		((struct parserData *)param)->itemptr = ((struct parserData *)param)->listptr->first_string;

		int row = 0;
		for (row = 0; ((struct parserData *)param)->itemptr != 0; ++row)
		  {
			g15r_renderString (((struct parserData *)param)->canvas, ((struct parserData *)param)->itemptr->string, row, G15_TEXT_SMALL, 0, 0);
			((struct parserData *)param)->itemptr = ((struct parserData *)param)->itemptr->next_string;
		  }
	}
    break;

  case 49:
#line 517 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		((struct parserData *)param)->listptr = (yyvsp[(2) - (3)].strList);
		((struct parserData *)param)->itemptr = ((struct parserData *)param)->listptr->first_string;

		int row = 0;
		for (row = 0; ((struct parserData *)param)->itemptr != 0; ++row)
		  {
			g15r_renderString (((struct parserData *)param)->canvas, ((struct parserData *)param)->itemptr->string, row, G15_TEXT_MED, 0, 0);
			((struct parserData *)param)->itemptr = ((struct parserData *)param)->itemptr->next_string;
		  }
	}
    break;

  case 50:
#line 534 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		((struct parserData *)param)->listptr = (yyvsp[(2) - (3)].strList);
		((struct parserData *)param)->itemptr = ((struct parserData *)param)->listptr->first_string;

		int row = 0;
		for (row = 0; ((struct parserData *)param)->itemptr != 0; ++row)
		  {
			g15r_renderString (((struct parserData *)param)->canvas, ((struct parserData *)param)->itemptr->string, row, G15_TEXT_LARGE, 0, 0);
			((struct parserData *)param)->itemptr = ((struct parserData *)param)->itemptr->next_string;
		  }
	}
    break;

  case 51:
#line 551 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		((struct parserData *)param)->listptr = (yyvsp[(6) - (7)].strList);
		((struct parserData *)param)->itemptr = ((struct parserData *)param)->listptr->first_string;

		int row = 0;
		for (row = 0; ((struct parserData *)param)->itemptr != 0; ++row)
		  {
			if ((yyvsp[(5) - (7)].number))
			  {
			  	unsigned int dispcol = 0;
				unsigned int len = strlen (((struct parserData *)param)->itemptr->string);
				
				dispcol = getDispCol (len, (yyvsp[(4) - (7)].number), (yyvsp[(5) - (7)].number));
				g15r_renderString (((struct parserData *)param)->canvas, ((struct parserData *)param)->itemptr->string, row, (yyvsp[(4) - (7)].number), dispcol, (yyvsp[(3) - (7)].number));
			  }
			else
			  g15r_renderString (((struct parserData *)param)->canvas, ((struct parserData *)param)->itemptr->string, row, (yyvsp[(4) - (7)].number), (yyvsp[(2) - (7)].number), (yyvsp[(3) - (7)].number));
			((struct parserData *)param)->itemptr = ((struct parserData *)param)->itemptr->next_string;
		  }
	}
    break;

  case 52:
#line 577 "g15composer.y"
    {
	}
    break;

  case 53:
#line 583 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		int sendCmd = 1;
		int LEDon = (yyvsp[(3) - (4)].number);
		((struct parserData *)param)->mkey_state |= G15DAEMON_MKEYLEDS;
		switch ((yyvsp[(2) - (4)].number))
		  {
		  case 0:
		    {
		      if (LEDon != 0)
			((struct parserData *)param)->mkey_state |= G15_LED_M1 | G15_LED_M2 | G15_LED_M3;
		      else
			((struct parserData *)param)->mkey_state &= ~G15_LED_M1 & ~G15_LED_M2 & ~G15_LED_M3;
		      break;
		    }
		  case 1:
		    {
		      if (LEDon != 0)
			((struct parserData *)param)->mkey_state |= G15_LED_M1;
		      else
			((struct parserData *)param)->mkey_state &= ~G15_LED_M1;
		      break;
		    }
		  case 2:
		    {
		      if (LEDon != 0)
			((struct parserData *)param)->mkey_state |= G15_LED_M2;
		      else
			((struct parserData *)param)->mkey_state &= ~G15_LED_M2;
		      break;
		    }
		  case 3:
		    {
		      if (LEDon != 0)
			((struct parserData *)param)->mkey_state |= G15_LED_M3;
		      else
			((struct parserData *)param)->mkey_state &= ~G15_LED_M3;
		      break;
		    }
		  default:
		    {
		      sendCmd = 0;
		      break;
		    }
		  }
		((struct parserData *)param)->cmd_only=1;
		if (sendCmd == 1)
		  send (((struct parserData *)param)->g15screen_fd, &((struct parserData *)param)->mkey_state, 1, MSG_OOB);
	}
    break;

  case 54:
#line 637 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
	        g15_send_cmd(((struct parserData *)param)->g15screen_fd,G15DAEMON_BACKLIGHT, (yyvsp[(2) - (3)].number));
		((struct parserData *)param)->cmd_only=1;

	}
    break;

  case 55:
#line 648 "g15composer.y"
    {
		if (((struct parserData *)param)->background == 1)
		  return (0);
		char msgbuf = G15DAEMON_CONTRAST | (yyvsp[(2) - (3)].number);
		send (((struct parserData *)param)->g15screen_fd, &msgbuf, 1, MSG_OOB);
		((struct parserData *)param)->cmd_only=1;
	}
    break;

  case 56:
#line 659 "g15composer.y"
    {
		struct parserData *newParam = (struct parserData *) malloc (sizeof (struct parserData));
		newParam->background = 0;
		newParam->threads = ((struct parserData *)param)->threads;
		newParam->fifo_filename = strdup ((yyvsp[(2) - (3)].string));

	  	pthread_create (&newParam->thread, NULL, threadEntry, (void *) newParam);
		add_thread (newParam);
		free ((yyvsp[(2) - (3)].string));
	}
    break;

  case 57:
#line 673 "g15composer.y"
    {
		((struct parserData *)param)->leaving = 1;
	}
    break;


/* Line 1267 of yacc.c.  */
#line 2135 "g15composer.tab.c"
      default: break;
    }
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
      {
	YYSIZE_T yysize = yysyntax_error (0, yystate, yychar);
	if (yymsg_alloc < yysize && yymsg_alloc < YYSTACK_ALLOC_MAXIMUM)
	  {
	    YYSIZE_T yyalloc = 2 * yysize;
	    if (! (yysize <= yyalloc && yyalloc <= YYSTACK_ALLOC_MAXIMUM))
	      yyalloc = YYSTACK_ALLOC_MAXIMUM;
	    if (yymsg != yymsgbuf)
	      YYSTACK_FREE (yymsg);
	    yymsg = (char *) YYSTACK_ALLOC (yyalloc);
	    if (yymsg)
	      yymsg_alloc = yyalloc;
	    else
	      {
		yymsg = yymsgbuf;
		yymsg_alloc = sizeof yymsgbuf;
	      }
	  }

	if (0 < yysize && yysize <= yymsg_alloc)
	  {
	    (void) yysyntax_error (yymsg, yystate, yychar);
	    yyerror (yymsg);
	  }
	else
	  {
	    yyerror (YY_("syntax error"));
	    if (yysize != 0)
	      goto yyexhaustedlab;
	  }
      }
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse look-ahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
	{
	  /* Return failure if at end of input.  */
	  if (yychar == YYEOF)
	    YYABORT;
	}
      else
	{
	  yydestruct ("Error: discarding",
		      yytoken, &yylval);
	  yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse look-ahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule which action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;


      yydestruct ("Error: popping",
		  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  *++yyvsp = yylval;


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEOF && yychar != YYEMPTY)
     yydestruct ("Cleanup: discarding lookahead",
		 yytoken, &yylval);
  /* Do not reclaim the symbols of the rule which action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
		  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  /* Make sure YYID is used.  */
  return YYID (yyresult);
}


#line 678 "g15composer.y"


